Learn R Programming

bibliorefer (version 0.1.3)

arquiwos_une: Function that consolidates files in BibTeX format from the WoS database.

Description

The function combines the various Bibtex files from the WoS collection into a single file. The function returns a list with the sequence of grouped files and a dataframe with the final Bibtex database.

Usage

arquiwos_une(arquivos)

Value

This function returns a dataframe containing the metadata for the articles in the WoS collection.

Arguments

arquivos

is the database that contains the metadata in Bibtex format for the articles in the WoS collection.

References

Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier

Examples

Run this code

#Call the arquiwos_une function

file_db <- system.file("extdata","savedrecs.bib", package = "bibliorefer")
cabec_wos = TRUE
quoaspa_wos = ""
arquivos <- entrada_wos(file_db, cabec_wos, quoaspa_wos)

#Call the arquiwos_une function
base_arquiwos <- arquiwos_une(arquivos)
base_arquiwos



Run the code above in your browser using DataLab