Learn R Programming

bibliorefer (version 0.1.3)

convert_biblioscopus: Function that converts the BibTeX format from the Scopus database to a CSV spreadsheet.

Description

The function converts the Scopus database metadata file from Bibtex format to a CSV spreadsheet. The function's input is a file with the .bib extension. The function returns a dataframe.

Usage

convert_biblioscopus(variavel1, variavel2)

Value

This function returns a dataframe containing the metadata for the articles in the Scopus collection.

Arguments

variavel1

is the database that contains the input and output keys for metadata in Bibtex format for articles in the Scopus collection.

variavel2

is the database that contains the metadata in Bibtex format for articles in the Scopus collection.

References

Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier

Examples

Run this code

#Call the convert_biblioscopus function

file_db <- system.file("extdata","scopus.bib", package = "bibliorefer")
cabec = TRUE
quoaspa = ""
base_scopus <- entrada_scopus(file_db, cabec, quoaspa)
base_scopus <- as.data.frame(base_scopus)
variavel1 <- base_scopus$V1
variavel2 <- base_scopus$V2

#Call the convert_biblioscopus function
font_scopus <- convert_biblioscopus(variavel1,variavel2)
font_scopus



Run the code above in your browser using DataLab