Learn R Programming

bibliorefer (version 0.1.3)

convert_bibliowos: Function that converts the BibTeX format from the WoS database to a CSV spreadsheet.

Description

The function converts the WoS database metadata file from Bibtex format to a CSV spreadsheet. The function's input is a file with the .bib extension. The function returns a dataframe.

Usage

convert_bibliowos(arquivos)

Value

This function returns a dataframe containing the metadata for the articles in the WoS collection.

Arguments

arquivos

is the database that contains the metadata in Bibtex format for the articles in the WoS collection.

References

Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier

Examples

Run this code

#Call the convert_bibliowos function

file_db <- system.file("extdata","savedrecs.bib", package = "bibliorefer")
cabec_wos = TRUE
quoaspa_wos = ""
arquivos <- entrada_wos(file_db, cabec_wos, quoaspa_wos)

#Call the convert_bibliowos function
font_wos <- convert_bibliowos(arquivos)
font_wos



Run the code above in your browser using DataLab