Learn R Programming

bibliorefer (version 0.1.3)

entrada_wos: Function that generates the test database

Description

The example_database function reads a csv file available on the computer system and returns a dataframe as an example of a database to be used by the functions of the bibliorefer package

Usage

entrada_wos(path_date, cabec_wos, quoaspa_wos)

Value

This function return is a dataframe with database

Arguments

path_date

is a directory path containing the bib file

cabec_wos

is the header for wos files in bib format

quoaspa_wos

is the separator wos for files in bib format

References

Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier

Examples

Run this code

#Call the example_database function

file_db <- system.file("extdata","savedrecs.bib", package = "bibliorefer")
cabec_wos = TRUE
quoaspa_wos = ""
date_wosrefer <- entrada_wos(file_db, cabec_wos, quoaspa_wos)
date_wosrefer

Run the code above in your browser using DataLab