Learn R Programming

bibliorefer (version 0.1.2)

tabel_gera: Function of scientific information

Description

This function receives a dataframe with scientific production data and returns a list object with information about articles, authors and journals.

Usage

tabel_gera(input_date)

Value

The function return a list object containing three dataframes with ordered lists of articles, authors and journals.

Arguments

input_date

is a dataframe with the scientific production database

References

Aria, M. & Cuccurullo, C. (2017) bibliometrix: An R-tool for comprehensive science mapping analysis, Journal of Informetrics, 11(4), pp 959-975, Elsevier

Examples

Run this code

#Call the tabel_gera function
file_db <- system.file("extdata","example_database.csv",package = "bibliorefer")
separator <- ";"
input_date <- example_database(file_db, separator)
scientific_inf <- tabel_gera(input_date)
scientific_inf


Run the code above in your browser using DataLab